@@ -1391,7 +1391,9 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 
 		if (isCopy) // "Save a Copy As..." command
 		{
+			_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_OFF);
 			_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, _scratchDocDefault);
+			_pscratchTilla->execute(SCI_SETMODEVENTMASK, MODEVENTMASK_ON);
 			return SavingStatus::SaveOK;	//all done - we don't change the current buffer's path to "fullpath", since it's "Save a Copy As..." action.
 		}
 
@@ -2005,3 +2007,16 @@ size_t FileManager::docLength(Buffer* buffer) const
 	_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, curDoc);
 	return docLen;
 }
+
+
+void FileManager::removeHotSpot(Buffer* buffer) const
+{
+	Document curDoc = _pscratchTilla->execute(SCI_GETDOCPOINTER);
+	_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, buffer->_doc);
+
+	_pscratchTilla->execute(SCI_SETINDICATORCURRENT, URL_INDIC);
+	size_t docLen = _pscratchTilla->getCurrentDocLen();
+	_pscratchTilla->execute(SCI_INDICATORCLEARRANGE, 0, docLen);
+
+	_pscratchTilla->execute(SCI_SETDOCPOINTER, 0, curDoc);
+}
