@@ -16,19 +16,20 @@
 
 #pragma once
 
-//
-// Notepad++ version: begin
-//
-#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.7.5"
+
+//************ Notepad++ version **************************
+
+#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.7.6"
 
 // should be X.Y : ie. if VERSION_DIGITALVALUE == 4, 7, 1, 0 , then X = 4, Y = 71
 // ex : #define VERSION_VALUE L"5.63\0"
-#define VERSION_INTERNAL_VALUE L"8.75\0"
+#define VERSION_INTERNAL_VALUE L"8.76\0"
 
-#define VERSION_PRODUCT_VALUE L"8.7.5\0"
-#define VERSION_DIGITALVALUE 8, 7, 5, 0
+#define VERSION_PRODUCT_VALUE L"8.7.6\0"
+#define VERSION_DIGITALVALUE 8, 7, 6, 0
+
+//**********************************************************
 
-// Notepad++ version: end
 
 
 #ifndef IDC_STATIC
@@ -371,54 +372,58 @@
 #define IDR_FILEBROWSER             1529
 #define IDR_CLOSETAB                1530
 #define IDR_CLOSETAB_INACT          1531
-#define IDR_CLOSETAB_HOVERIN        1532
-#define IDR_CLOSETAB_HOVERONTAB     1533
-#define IDR_CLOSETAB_PUSH           1534
-#define IDR_FUNC_LIST_ICO           1535
-#define IDR_DOCMAP_ICO              1536
-#define IDR_PROJECTPANEL_ICO        1537
-#define IDR_CLIPBOARDPANEL_ICO      1538
-#define IDR_ASCIIPANEL_ICO          1539
-#define IDR_DOCSWITCHER_ICO         1540
-#define IDR_FILEBROWSER_ICO         1541
-#define IDR_FILEMONITORING          1542
-#define IDR_CLOSETAB_DM             1543
-#define IDR_CLOSETAB_INACT_DM       1544
-#define IDR_CLOSETAB_HOVERIN_DM     1545
-#define IDR_CLOSETAB_HOVERONTAB_DM  1546
-#define IDR_CLOSETAB_PUSH_DM        1547
-#define IDR_DOCLIST                 1548
-#define IDR_DOCLIST_ICO             1549
+#define IDR_CLOSETAB_INACT_EMPTY    1532
+#define IDR_CLOSETAB_HOVERIN        1533
+#define IDR_CLOSETAB_HOVERONTAB     1534
+#define IDR_CLOSETAB_PUSH           1535
+#define IDR_FUNC_LIST_ICO           1536
+#define IDR_DOCMAP_ICO              1537
+#define IDR_PROJECTPANEL_ICO        1538
+#define IDR_CLIPBOARDPANEL_ICO      1539
+#define IDR_ASCIIPANEL_ICO          1540
+#define IDR_DOCSWITCHER_ICO         1541
+#define IDR_FILEBROWSER_ICO         1542
+#define IDR_FILEMONITORING          1543
+#define IDR_CLOSETAB_DM             1544
+#define IDR_CLOSETAB_INACT_DM       1545
+#define IDR_CLOSETAB_INACT_EMPTY_DM 1546
+#define IDR_CLOSETAB_HOVERIN_DM     1547
+#define IDR_CLOSETAB_HOVERONTAB_DM  1548
+#define IDR_CLOSETAB_PUSH_DM        1549
+#define IDR_DOCLIST                 1550
+#define IDR_DOCLIST_ICO             1551
 
-#define IDR_FILEBROWSER_ICO2        1550
-#define IDR_FILEBROWSER_ICO_DM      1551
-#define IDR_FUNC_LIST_ICO2          1552
-#define IDR_FUNC_LIST_ICO_DM        1553
-#define IDR_DOCMAP_ICO2             1554
-#define IDR_DOCMAP_ICO_DM           1555
-#define IDR_DOCLIST_ICO2            1556
-#define IDR_DOCLIST_ICO_DM          1557
-#define IDR_PROJECTPANEL_ICO2       1558
-#define IDR_PROJECTPANEL_ICO_DM     1559
-#define IDR_CLIPBOARDPANEL_ICO2     1560
-#define IDR_CLIPBOARDPANEL_ICO_DM   1561
-#define IDR_ASCIIPANEL_ICO2         1562
-#define IDR_ASCIIPANEL_ICO_DM       1563
-#define IDR_FIND_RESULT_ICO2        1564
-#define IDR_FIND_RESULT_ICO_DM      1565
+#define IDR_FILEBROWSER_ICO2        1552
+#define IDR_FILEBROWSER_ICO_DM      1553
+#define IDR_FUNC_LIST_ICO2          1554
+#define IDR_FUNC_LIST_ICO_DM        1555
+#define IDR_DOCMAP_ICO2             1556
+#define IDR_DOCMAP_ICO_DM           1557
+#define IDR_DOCLIST_ICO2            1558
+#define IDR_DOCLIST_ICO_DM          1559
+#define IDR_PROJECTPANEL_ICO2       1560
+#define IDR_PROJECTPANEL_ICO_DM     1561
+#define IDR_CLIPBOARDPANEL_ICO2     1562
+#define IDR_CLIPBOARDPANEL_ICO_DM   1563
+#define IDR_ASCIIPANEL_ICO2         1564
+#define IDR_ASCIIPANEL_ICO_DM       1565
+#define IDR_FIND_RESULT_ICO2        1566
+#define IDR_FIND_RESULT_ICO_DM      1567
 
-#define IDR_PINTAB                  1566
-#define IDR_PINTAB_INACT            1567
-#define IDR_PINTAB_HOVERIN          1568
-#define IDR_PINTAB_HOVERONTAB       1569
-#define IDR_PINTAB_PINNED           1570
-#define IDR_PINTAB_PINNEDHOVERIN    1571
-#define IDR_PINTAB_DM               1572
-#define IDR_PINTAB_INACT_DM         1573
-#define IDR_PINTAB_HOVERIN_DM       1574
-#define IDR_PINTAB_HOVERONTAB_DM    1575
-#define IDR_PINTAB_PINNED_DM        1576
-#define IDR_PINTAB_PINNEDHOVERIN_DM 1577
+#define IDR_PINTAB                  1568
+#define IDR_PINTAB_INACT            1569
+#define IDR_PINTAB_INACT_EMPTY      1570
+#define IDR_PINTAB_HOVERIN          1571
+#define IDR_PINTAB_HOVERONTAB       1572
+#define IDR_PINTAB_PINNED           1573
+#define IDR_PINTAB_PINNEDHOVERIN    1574
+#define IDR_PINTAB_DM               1575
+#define IDR_PINTAB_INACT_DM         1576
+#define IDR_PINTAB_INACT_EMPTY_DM   1577
+#define IDR_PINTAB_HOVERIN_DM       1578
+#define IDR_PINTAB_HOVERONTAB_DM    1579
+#define IDR_PINTAB_PINNED_DM        1580
+#define IDR_PINTAB_PINNEDHOVERIN_DM 1581
 
 #define ID_MACRO                           20000
 //                                     O     .
@@ -558,7 +563,7 @@
 
 #define IDD_GOLINE        2000
 #define ID_GOLINE_EDIT    (IDD_GOLINE + 1)
-#define ID_CURRLINE        (IDD_GOLINE + 2)
+#define ID_CURRLINE_EDIT   (IDD_GOLINE + 2)
 #define ID_LASTLINE        (IDD_GOLINE + 3)
 #define ID_URHERE_STATIC           (IDD_GOLINE + 4)
 #define ID_UGO_STATIC                 (IDD_GOLINE + 5)
@@ -714,7 +719,7 @@
 	#define NPPM_INTERNAL_DOCMODIFIEDBYREPLACEALL       (NOTEPADPLUS_USER_INTERNAL + 79)
 	#define NPPM_INTERNAL_DRAWTABBARPINBUTTON           (NOTEPADPLUS_USER_INTERNAL + 80)
 	#define NPPM_INTERNAL_DRAWTABBARCLOSEBUTTON         (NOTEPADPLUS_USER_INTERNAL + 81)
-	//#define NPPM_INTERNAL_REFRESHTABAR                  (NOTEPADPLUS_USER_INTERNAL + 82)
+	#define NPPM_INTERNAL_DRAWINACTIVETABBARBUTTON      (NOTEPADPLUS_USER_INTERNAL + 82)
 	#define NPPM_INTERNAL_REDUCETABBAR                  (NOTEPADPLUS_USER_INTERNAL + 83)
 	#define NPPM_INTERNAL_LOCKTABBAR                    (NOTEPADPLUS_USER_INTERNAL + 84)
 	#define NPPM_INTERNAL_DRAWINACIVETAB                (NOTEPADPLUS_USER_INTERNAL + 85)
@@ -739,6 +744,7 @@
 	#define NPPM_INTERNAL_LWALIGN                       (NOTEPADPLUS_USER_INTERNAL + 104)
 	#define NPPM_INTERNAL_LWINDENT                      (NOTEPADPLUS_USER_INTERNAL + 105)
 	#define NPPM_INTERNAL_CHECKDOCSTATUS                (NOTEPADPLUS_USER_INTERNAL + 106)
+	#define NPPM_INTERNAL_HIDEMENURIGHTSHORTCUTS        (NOTEPADPLUS_USER_INTERNAL + 107)
 
 
 
